hstrat.hstrat.HereditaryStratumOrderedStoreTree
===============================================

.. currentmodule:: hstrat.hstrat

.. autoclass:: HereditaryStratumOrderedStoreTree

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HereditaryStratumOrderedStoreTree.Clone
      ~HereditaryStratumOrderedStoreTree.DelRanks
      ~HereditaryStratumOrderedStoreTree.DepositStratum
      ~HereditaryStratumOrderedStoreTree.GetColumnIndexOfRank
      ~HereditaryStratumOrderedStoreTree.GetNumStrataRetained
      ~HereditaryStratumOrderedStoreTree.GetRankAtColumnIndex
      ~HereditaryStratumOrderedStoreTree.GetRetainedRanks
      ~HereditaryStratumOrderedStoreTree.GetStratumAtColumnIndex
      ~HereditaryStratumOrderedStoreTree.IterRankDifferentia
      ~HereditaryStratumOrderedStoreTree.__init__
   
   

   
   
   